@@ -119,7 +119,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelCreateBatchCancelFlowUrl(self, request):
-        """指定需要批量撤销的签署流程Id，获取批量撤销链接
+        """指定需要批量撤销的签署流程Id，获取批量撤销链接 - 不建议使用此接口，可使用ChannelBatchCancelFlows
         客户指定需要撤销的签署流程Id，最多100个，超过100不处理；
         接口调用成功返回批量撤销合同的链接，通过链接跳转到电子签小程序完成批量撤销;
         可以撤回：未全部签署完成；不可以撤回（终态）：已全部签署完成、已拒签、已过期、已撤回。
@@ -478,7 +478,8 @@ class EssbasicClient(AbstractClient):
 
 
     def CreateChannelFlowEvidenceReport(self, request):
-        """创建出证报告，返回报告 ID
+        """创建出证报告，返回报告 ID。需要配合出证套餐才能调用。
+        出证需要一定时间，建议调用创建出证24小时之后再通过DescribeChannelFlowEvidenceReport进行查询。
 
         :param request: Request instance for CreateChannelFlowEvidenceReport.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateChannelFlowEvidenceReportRequest`
@@ -672,6 +673,35 @@ class EssbasicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeExtendedServiceAuthInfo(self, request):
+        """查询企业扩展服务授权信息，企业经办人需要时企业超管或者法人
+
+        :param request: Request instance for DescribeExtendedServiceAuthInfo.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.DescribeExtendedServiceAuthInfoRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.DescribeExtendedServiceAuthInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeExtendedServiceAuthInfo", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeExtendedServiceAuthInfoResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeFlowDetailInfo(self, request):
         """此接口（DescribeFlowDetailInfo）用于查询合同(签署流程)的详细信息。
 
@@ -820,6 +850,35 @@ class EssbasicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyExtendedService(self, request):
+        """修改（操作）企业扩展服务 ，企业经办人需要时企业超管或者法人
+
+        :param request: Request instance for ModifyExtendedService.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.ModifyExtendedServiceRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ModifyExtendedServiceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyExtendedService", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyExtendedServiceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def OperateChannelTemplate(self, request):
         """此接口（OperateChannelTemplate）用于针对渠道模板库中的模板对子客企业可见性的查询和设置，不会直接分配渠道模板给子客企业。
         1、OperateType=select时：
